@@ -1,50 +1,53 @@
 package CGI::Kwiki::Template;
-$VERSION = '0.11';
+$VERSION = '0.12';
 use strict;
-use CGI::Kwiki;
-
-attribute 'driver';
-
-sub new {
-    my ($class, $driver) = @_;
-    my $self = bless {}, $class;
-    $self->driver($driver);
-    return $self;
-}
+use base 'CGI::Kwiki';
 
 sub header {
     my ($self) = @_;
-    my $page_id = $self->driver->cgi->page_id;
-    my $top_page = $self->driver->config->top_page;
-    my $kwiki_image = $self->driver->config->kwiki_image;
+    my $page_id = $self->cgi->page_id;
+    my $top_page = $self->config->top_page;
+    my $kwiki_image = $self->config->kwiki_image;
     my $image_html = '';
     if (defined $kwiki_image) {
-        $image_html = 
-          qq{<img src="$kwiki_image" alt="[$top_page]" border=0 align="right">};
+        $image_html = qq{<img src="$kwiki_image" border="0">};
     }
-    my $title_prefix = $self->driver->config->title_prefix;
+    my $title_prefix = $self->config->title_prefix;
+    my $sister_html = '';
     <<END;
 <!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML//EN">
 <html>
 <head>
 <title>$title_prefix: $page_id</title>
 </head>
-<body BGCOLOR="white">
+<body bgcolor=#FFFFFF link=#d06040 vlink=#806040>
+<table width=600 cellspacing=0 cellpadding=3>
+<tr>
+<td align=center valign=top width=90>
+<a href="?$top_page">
+$image_html
+</a>
+$sister_html
+</td>
+<td width=510 valign=center>
 <h1>
-    <a href="?$top_page">
-    $image_html
-    </a>
-    <a href="index.cgi?action=search&search=$page_id">$page_id</a>
+<a href="index.cgi?action=search&search=$page_id">
+$page_id
+</a>
 </h1>
 <form method="post" action="index.cgi"
       enctype="application/x-www-form-urlencoded">
 <a href="index.cgi?$top_page">$top_page</a> | 
 <a href="index.cgi?RecentChanges">RecentChanges</a> | 
-<a href="index.cgi?action=prefs">Preferences</a> |
+<!-- <a href="index.cgi?action=prefs">Preferences</a> | -->
 Search: 
-<input type="text" name="search" size="20" />
+<input type="text" name="search" size="15" />
 <input type="hidden" name="action" value="search" />
 </form>
+</td>
+</tr><tr>
+<td align=center valign=top><font size=-1><br></font></td>
+<td>
 <hr>
 END
 }
@@ -52,22 +55,29 @@ END
 sub footer {
     my ($self) = @_;
     <<END;
-<hr>
 </body>
 </html>
 END
 }
 
 sub display_footer {
-    my ($self) = @_;
-    my $page_id = $self->driver->cgi->page_id;
-    <<END;
-<hr>
+    my $self = shift;
+    my $page_id = $self->cgi->page_id;
+<<END;
+<p>&nbsp;</td>
+</tr><tr>
+<td align=center>
 <form>
 <input type="submit" value="EDIT">
 <input type="hidden" name="action" value="edit">
 <input type="hidden" name="page_id" value="$page_id">
 </form>
+</td>
+<td align=left valign=top>
+
+</td>
+</tr>
+</table>
 </body>
 </html>
 END
@@ -75,7 +85,7 @@ END
 
 sub edit_body {
     my ($self, $wiki_text) = @_;
-    my $page_id = $self->driver->cgi->page_id;
+    my $page_id = $self->cgi->page_id;
     return <<END;
 <form method="post" 
       action="index.cgi" 
@@ -92,16 +102,13 @@ sub edit_body {
 <br><br>
 <input type="submit" name="button" value="SAVE" />
 <input type="submit" name="button" value="PREVIEW" />
-<br><br>
-(Visit <a href="index.cgi?action=prefs">Preferences</a> 
-to set your user name.) 
 </form>
 END
 }
 
 sub display_body {
-    my ($self, $body) = @_;
-    return $body;
+    my ($self, $display) = @_;
+    return "<wiki>\n$display</wiki>\n";
 }
 
 sub preview_body {
@@ -113,30 +120,6 @@ $preview
 END
 }
 
-sub search_body {
-    my ($self, $result) = @_;
-    return $result;
-}
-
-sub changes_body {
-    my ($self, $result) = @_;
-    return $result;
-}
-
-sub prefs_body {
-    my ($self) = @_;
-<<END;
-<form>
-<br>
-UserName: &nbsp;
-<input type="text" name="user_name" size="20" /> 
-<br><br>
-<input type="submit" name="button" value="ENTER" />
-<input type="hidden" name="action" value="prefs" />
-</form>
-END
-}
-
 1;
 
 =head1 NAME 
